.. _installation:

Installation
============

This application requires Django_ 1.2 or higher and it is only prerequisite
before ``django-guardian`` may be used. 

In order to install ``django-guardian`` simply use ``pip``::

   pip install django-guardian

or ``easy_install``::

   easy_install django-guardian

This would be enough to run ``django-guardian``. However, in order to run tests
or boundled example application, there are some other requirements. See more
details about the topics:

- :ref:`Testing <testing>`
- :ref:`Example project <example-project>`

.. _django: http://www.djangoproject.com/

